==> tuia-advert-center-api-2.2.18-sources.jar: cn/com/duiba/tuia/core/api/dto/advert/EncourageMaterialDto.java <==
package cn.com.duiba.tuia.core.api.dto.advert;

import java.io.Serializable;

/**
 * @author wangting
 * @version 1.0
 * @ClassName: EncourageMaterialDto
 * Function: 激励广告素材 实体
 * Date:     2019/5/30 0030 下午 3:22
 */
public class EncourageMaterialDto implements Serializable {


    private static final long serialVersionUID = 9207357625702074052L;

    /**素材Id*/
    private Long materialId;

    /**弹层ID*/
    private Long windId;

    /**广告ID*/
    private Long advertId;

    /**激励样式 1-金币1 ; 2-金币2 ; 3-宝箱*/
    private Integer encourageType;

    /**激励金额*/
    private Long encourageFee;

    /**激励金额样式ID*/
    private Long encourageFeeStye;

    /**动效ID*/
    private Long animationEffect;

    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }

    public Long getWindId() {
        return windId;
    }

    public void setWindId(Long windId) {
        this.windId = windId;
    }

    public Integer getEncourageType() {
        return encourageType;
    }

    public void setEncourageType(Integer encourageType) {
        this.encourageType = encourageType;
    }

    public Long getEncourageFee() {
        return encourageFee;
    }

    public void setEncourageFee(Long encourageFee) {
        this.encourageFee = encourageFee;
    }

    public Long getEncourageFeeStye() {
        return encourageFeeStye;
    }

    public void setEncourageFeeStye(Long encourageFeeStye) {
        this.encourageFeeStye = encourageFeeStye;
    }

    public Long getAnimationEffect() {
        return animationEffect;
    }

    public void setAnimationEffect(Long animationEffect) {
        this.animationEffect = animationEffect;
    }
}

==> tuia-advert-center-api-2.2.44-sources.jar: cn/com/duiba/tuia/core/api/dto/advert/EncourageMaterialDto.java <==
package cn.com.duiba.tuia.core.api.dto.advert;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * @author wangting
 * @version 1.0
 * @ClassName: EncourageMaterialDto
 * Function: 激励广告素材 实体
 * Date:     2019/5/30 0030 下午 3:22
 */
public class EncourageMaterialDto implements Serializable {


    private static final long serialVersionUID = 9207357625702074052L;

    /**素材Id*/
    private Long materialId;

    /**弹层ID*/
    private Long windId;

    /**广告ID*/
    private Long advertId;

    /**激励样式 1-金币1 ; 2-金币2 ; 3-宝箱*/
    private Integer encourageType;

    /**激励金额*/
    private Long encourageFee;

    /**激励金额样式ID*/
    private Long encourageFeeStye;

    /**动效ID*/
    private Long animationEffect;

    /**默认状态:0-非默认弹层，1-默认弹层*/
    private Integer isDefault;

    /**审核状态:0-审核通过，1-新增，2-提交审核，3-审核拒绝*/
    private Integer checkStatus;

    /**素材标签*/
    private List<String> materialTagNums;

    /**创建时间*/
    private Date gmtCreate;

    /**更新时间*/
    private Date gmtModified;

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Integer getIsDefault() {
        return isDefault;
    }

    public void setIsDefault(Integer isDefault) {
        this.isDefault = isDefault;
    }

    public Integer getCheckStatus() {
        return checkStatus;
    }

    public void setCheckStatus(Integer checkStatus) {
        this.checkStatus = checkStatus;
    }

    public List<String> getMaterialTagNums() {
        return materialTagNums;
    }

    public void setMaterialTagNums(List<String> materialTagNums) {
        this.materialTagNums = materialTagNums;
    }

    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }

    public Long getWindId() {
        return windId;
    }

    public void setWindId(Long windId) {
        this.windId = windId;
    }

    public Integer getEncourageType() {
        return encourageType;
    }

    public void setEncourageType(Integer encourageType) {
        this.encourageType = encourageType;
    }

    public Long getEncourageFee() {
        return encourageFee;
    }

    public void setEncourageFee(Long encourageFee) {
        this.encourageFee = encourageFee;
    }

    public Long getEncourageFeeStye() {
        return encourageFeeStye;
    }

    public void setEncourageFeeStye(Long encourageFeeStye) {
        this.encourageFeeStye = encourageFeeStye;
    }

    public Long getAnimationEffect() {
        return animationEffect;
    }

    public void setAnimationEffect(Long animationEffect) {
        this.animationEffect = animationEffect;
    }
}
